@@ -14,7 +14,7 @@ import six
 @six.add_metaclass(abc.ABCMeta)
 class ParserInterface(object):
     @abc.abstractmethod
-    def parse(self, text):  # pragma: no cover
+    def parse(self, device, text):  # pragma: no cover
         pass
 
 
