@@ -9,10 +9,11 @@ from __future__ import absolute_import, print_function
 import sys
 
 from subprocrunner import SubprocessRunner
-from tcconfig._const import Tc
-from tcconfig._converter import Humanreadable, HumanReadableTime
 from typepy import RealNumber
 
+from tcconfig._const import Tc
+from tcconfig._converter import HumanReadableBits, HumanReadableTime
+
 
 DEADLINE_TIME = 3  # [sec]
 ASSERT_MARGIN = 0.5
@@ -40,7 +41,7 @@ def is_invalid_param(rate, delay, packet_loss, packet_duplicate, corrupt, reorde
     )
 
     try:
-        Humanreadable(rate, kilo_size=1000).to_bit()
+        HumanReadableBits(rate, kilo_size=1000).to_bits()
     except (TypeError, ValueError):
         pass
     else:
